@@ -108,7 +108,7 @@ pcacrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
            as.integer(nbblock),
            as.integer(nbpoint),
            pointmap = as.integer(pointmap),
-           tst = as.single(tst),
+           tst = as.double(tst),
            as.integer(tstsize),
            as.integer(count),
            as.integer(seed),
@@ -282,7 +282,7 @@ pcacrc <- function(tfrep, tfspec = numeric(dim(tfrep)[2]), grida = 10,
            as.double(sqmodulus),
            beemap= as.double(beemap),
            as.integer(pcamap),
-           as.single(rate),
+           as.double(rate),
            as.integer(sigsize),
            as.integer(nscale),
            as.integer(iteration),
@@ -350,13 +350,13 @@ pcafamily <-function(pcaridge,orientmap,
    z <- .C("Spca_family",
            as.double(pcaridge),
            as.integer(orientmap),
-           orderedmap = as.single(orderedmap),
+           orderedmap = as.double(orderedmap),
            chain = as.integer(chain),
            chainnb = as.integer(nbchain),
            as.integer(sigsize),
            as.integer(nscale),
            as.integer(bstep),
-           as.single(threshold),
+           as.double(threshold),
            as.integer(maxchnlng),
            PACKAGE="Rwave")
 	
